<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_CH">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Tsindrio raha hiverina amin&apos;ny rindran&apos;asa</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Nalaina</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Diovina</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 Zavatra</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Antonta-taratasy fenoina</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Anaran&apos;ny rakitra</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Avereno indray</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Ajanony</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Sokafy</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Ametraka Podcat amin&apos;ny Youtube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Lohateny</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Fanazavana</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Mpamorona</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Solaitra</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Tranon-kala</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Rakitra</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Haingo</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl + T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Sary ambadika</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Lahabolana</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Fakana</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Ampiana amin&apos;ny io pejy io</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Ampiana amin&apos;ny pejy vaovao</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Ampiana amin&apos;ny tahirim-boky</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Pejy</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Pejy vaovao</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Tsy atao indray</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Ovaina ny sary ambadika</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl + Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Atao indray</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl + Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Teo aloha</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Pejy teo aloha</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Ao aorina</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Pejy ao aorina</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDpwn</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Fikarakarana ny rakitra</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl + D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Mpizaha tranon-kala</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl + W</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Tsipika kely</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Tsipika salasala</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Tsipika lehibe</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Fafotse kely</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Fafotse salasala</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Fafotse lehibe</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Avereno aseho io pejy io</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Aseho ny pejin&apos;ny fandraisana</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Aseho ny tobin-drohy</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Ampiana ny tobin-drohy</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Aseho ny solaitra</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Fafana ny mpiatiny</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Aseho ny safidy nofaritana</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Aseho ny tahirim-boky</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Aseho ny sehatr&apos;asan&apos;ny solosaina</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Mamorona fitoeran-drakitra vaovao</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Mamorona rakitra vaovao</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Manafatra rakitra</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Mandefa rakitra</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Manokatra pejy amin&apos;ny solaitra</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Asina dikamitovy ny mpiatiny voafidy</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Fafana ny dikamitovy ny mpiatiny voafidy</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Ampiana amin&apos;ny rakitra ity mpiatiny ity</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Soloina anarana ny mpiatiny</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Aseho ny fitaovana</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Ampiasana ny haben&apos;ny antonta-tarasy malalaka (16/9)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Ampiasana ny haben&apos;ny antonta-tarasy mahazatra (4/3)</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Ampiasana ny haben&apos;ny antonta-tarasy voasafidy manokana</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Ajanony ny fakana ny pejin&apos;ny tranon-kala</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Ahato ny fampisehoana</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Asehoy ny fafan-teny virtoaly</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Raiketo ho horonan-tsary ny fampisehoana</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Fafana ilay zavatra</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Fafana ny zavatra rehetra</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Fafana ny fanamarihana</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Fafana ny fanamarihana rehetra</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Fafana ny zavatra rehetra</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>penina</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Manamarika rakitra</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Fafany ilay fanamarihana</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Penina lehibe</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Asongadina</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Mpifantinana</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Mifantina sy manova zavatra</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Tanana</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Maka ampahan&apos;ny efijery</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Fakana manokana</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Maka ny fikandrana iray</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Mpiatin&apos;ny tranon-kala natsofoka</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Fakana mpiatin&apos;ny tranon-kala azo atsofoka</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Aseho amin&apos;ny efijery hita ny efijery ampiasana matetika</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Fafana ny fanamarihana rehetra</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Hafarana ny fiasan&apos;i eduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Jereo raha misy fanavaozana</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Zòma mahalehibe</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Zòma mahakely</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Tsipika</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Hidio</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Fafotse</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Loko</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Miverina</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Havia</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Manaraka</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Havanana</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Averina alefa indray</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Fandraisana</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Tobin-drohy</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Tobin-drohy</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Fafana ny pejy</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Safidy nofaritana</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Fafana</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Tahirim-boky</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Asehoy ny sehatr&apos;asa</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Lehibe kokoa</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Kelikely kokoa</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Fitoeran-drakitra vaovao</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Rakitra vaovao</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Manafatra</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Mandefa</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Sokafana amin&apos;ny solaitra</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Asina dikamitovy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fafana</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Ampiana amn&apos;ny rakitra iasana</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Ampiana amin&apos;ny rakitra misokatra ny mpiatiny voasafidy</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ampiana</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Soloina ny anarana</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Tapahana</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Adika</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Apetaka</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Efamira-tsoramiafina ambadika mazava</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Efamira-tsoramiafina ambadika maizina</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Atomboka ny fandraiketana ny efijery</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Fampidinana sy fampiakarana ny pejy</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Tondro laser</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Tondro laser virtoaly</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Manoratra tsipika</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Manoratra lahabolana</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Ampiana amn&apos;ny pejy ampiaisana ilay zavatra</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Ampiana amn&apos;ny pejy vaovao ilay zavatra</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Ampiana amn&apos;ny tahirim-boky ilay zavatra</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Mamorona pejy vaovao</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Manao dikamitovy ny pejy</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Manao dikamitovy an&apos;ilay pejy ampiasana</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Manafatra pejy</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Manafatra pejy ivelany</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Ahato</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Ahato ny fandraiketana ny Podcast</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Fanefena ny Podcast</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Fanefena ny fandraiketana ny Podcast</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>Alaina ny Flash</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>Alaina ny mpiatiny Flash</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Alaina ny tranon-kala</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Alaina ny mpiatin&apos;ny tranon-kala</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Alaina ny fikandrana</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Asehoy amin&apos;ny zavatra hita</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Ampatorina</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Fafan-teny virtoaly</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Faritra ambadika mazava</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Mazava</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Faritra ambadika maizina</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Maizina</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Raiketo</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Fitaovana</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Efijery maromaro</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Habe lehibe (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Habe antonony (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Habe safidina manokana</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Ajanony ny fakana</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Sokafy OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Afeno OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Afeno ny rindran&apos;asan&apos;i OpenBoard</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Alefaso</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Ampiasana ny zavatra</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Fafana ny ao ambadika</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Esorina ny ao ambadika</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Famantarana ilaina</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Anaran&apos;ny mpampiasa:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Teny fanalahidy:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Famantaranan&apos;ny Proxy</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Mifandray amin&apos;ny Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Anaran&apos;ny mpampiasa:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Teny fanalahidy:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Raiketo ny anaran&apos;ny mpampiasa sy ny teny fanalahidy ho an&apos;ny fampiasana manaraka</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>Isa famantaranaan&apos;ilay zavatra =</translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Tsy zakan&apos;ny andrefy tanjona ilay mpiatiny.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Fafao ny pejy</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Tena te hamafa pejy iray avy amin&apos;ilay rakitra &apos;%0&apos; voafidy ve ianao ?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Haben&apos;ny pejy</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Tranon-kala</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Misy fanavaozana azo alaina, te hande amin&apos;ny pejin&apos;ilay tranonkala ve ianao ?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Tsisy fanavaozana azo alaina</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Fanavaozana azo alaina</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Avaozy</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Fakana mpiatiny %1 tsy nety</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Fakana mpiatiny vita</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Fitaovana tsy fantatra karazana %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Ampiana zavatra</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Zaka daholo (%1)</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Mpiatiny tsy fantatra karazana %1</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Fafao ny pejy %1 amin&apos;ilay rakitra</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Pejy %1 voafafa</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Fanampiana rakitra tsy nety: nisy tsy fetezana tamin&apos;ny fandikana ny rakitra</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Atokony</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Avaho</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Loko</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Fanampiana ny sary amin&apos;ny tahirim-boky tsy nety</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>Sary nalaina</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Toetoetran&apos;ny tahiry</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Loko:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Bika:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Habe:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Hidio</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Maka ampahan&apos;ny efijery</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Maka ny efijery</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Aseho ny fanovana haingony</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Aseho ny solaitra amin&apos;ny efijery faharoa</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Aseho ny sehatr&apos;asa amin&apos;ny efijery faharoa</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Fiteoran-drakitra vaovao</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Pejy %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Manampy fitoeran-drakitra misy sary</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Manampy sary </translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Manampy pejy an&apos;ilay rakitra</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Dikamitovy-na rakitra %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Rakitra %1 nadika</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Fafao ny pejy</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Fafao ny rakitra</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Tena te hamafa an&apos;ilay rakitra &apos;%1&apos; ve ianao ?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Daba foana</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Tena te hanafoana an&apos;ilay daba ve ianao ?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Manafoana daba</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Daba voafoana</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Mamafa fitoeran-drakitra</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Tena te hamafa an&apos;ilay fitoeran-drakitra &apos;%1&apos; ve ianao sy ny mpiatiny rehetra ?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Tsisy fitoeran-drakitra voafidy!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Manokatra rakitra zaka</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Manafatra rakitra %1 ...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Nisy tsy fetezana ny fanafarana rakitra ...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Alaina daholo ny sary amin&apos;ilay fitoeran-drakitra</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fafao</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Foana</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Daba</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Manokatra rakitra</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Ampiana amin&apos;ilay rakitra ny sary rehetra</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Ny sary rehetra(%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>Tsy misy sary ilay fantina!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Tena te hamafa pejy %n avy amin&apos;ilay rakitra &apos;%1&apos; voafidy ve ianao ?</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>Tsy misy sary ilay fitoeran-drakitra</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Rakitra tsy misy lohateny</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>sary</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>horonan-tsary</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>Zavatra</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widgets</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Ny rakitra rehetra zaka (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Rakitra %1 voaraikitra</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Mampiditra pejy %1 amin&apos;ny %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Fanafarana nety.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Fanafarana ny rakitra %1 nety.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Manafatra rakitra %1 </translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Pejy %0</translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">Fandefasana tsy nety.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Ekena</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Ajanony</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Daba</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 pejy voadika</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 pejy voadika</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Mandika pejy %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (fandikana)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Mandika pejy %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 pejy voadika</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Maka rakitra</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ajanony</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pejy %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pejy %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Nisy fitandremana niseho tamin&apos;ny fandefasana ny rakitra</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Fandefasana nety.</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Alefa ho IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Alefa ho rakitra IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Mandefa ny rakitra ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Fandefasana nety.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Fandefasana tsy nety.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Pejy</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Alefa ho rakitra UBZ</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Mandefa rakitra ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Fandefasana nety.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Fandefasana %1 %2 amin&apos;ny %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Fandefasana nety.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">Fandefasana tsy nety.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Alefa ho rakitra PDF </translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Mandefa ny rakitra ...</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Alefa ho PDF</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Fandefasana nety.</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Alefa ho rakitra PDF </translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Mandefa ny pejy %1 amin&apos;ny %2</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Fandefasana nety.</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Mandefa rakitra ...</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Alefa ho PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Pejy</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Alefa ho data an&apos;ny tranon-kala</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Fandefasana rakitra ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Fandefasana nety.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Fandefasana tsy nety.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Alefa any amin&apos;ny mpitety ny tranon-kala</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Ampiana amin&apos;ilay pejy</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Apetraka ambadika</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Ampiana amin&apos;ny tahirim-boky</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Mombamomban&apos;ny zavatra</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Ampiana amin&apos;ny  zavatra tena tiana</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Zaraina</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hikaroka</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fafana</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Miverina any amn&apos;ilay fitoeran-drakitra</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Fafana amin&apos;ny  zavatra tena tiana</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Mamorona fitoeran-drakitra vaovao</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Avereno jerena ny rakitrin&apos;ny rafitra</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>Sary Nafarana</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Feo</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Sarimietsika</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Sary</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Sary ahetsika</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Fifandraisana</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Rindran&apos;asa</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Bika</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Tena tiana</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Fikarohana ny tranon-kala</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Daba</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Ekena</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ajanony</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Ampidiro ny anaran&apos;ilay fitoeran-drakitra vaovao</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Maka</translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Voahidy</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Hita amin&apos;ny efijery voavelatra</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Voahidy</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Hita amin&apos;ny efijery voavelatra</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Hande any amin&apos;ny fototr&apos;ilay mpiatiny</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Apetraka ambadika</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Type lahabolana eto&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Lokon&apos;ilay lahabolana</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Azo ovaina</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Tranon-kala</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Maka ...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Nampagatsiahana</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Ovaina ho fitaovana</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Andrefin&apos;ny rakitra mahazatra (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Manafatra rakitra %1 ...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Fanafarana ny rakitra %1 tsy nety.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Fanafarana nety.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Fanafarana tsy nety.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Manafatra rakitra %1 ...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Fanafarana nety.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Fanafarana ny rakitra %1 tsy nety.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Andrefin&apos;ilay sary (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>Fanafarana PDF tsy nety.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Manafatra pejy %1 amin&apos;ny %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Nisy tsy fetezana tamin&apos;ny fandefasana ny horonan-tsary amin&apos;ny tranon-kala anatiny (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Fandefasana amin&apos;ny tranon-kala anatiny mandeha %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Alefa</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Hiditra</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Eny</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Tsia</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ekena</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Hidio</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt; Ampidiro ny anaran&apos;ny mpampiasa sy ny teny fanalahidy ho an&apos;ny &quot;%1&quot; amin&apos;ny %2 &lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Tsy nety ny fidirana ami&apos;ny Proxy</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Tsy fetezana SSL

%1

%2

Tena tsy te hiraharaha an&apos;ireo tsy mety ho an&apos;ilay milina ve ianao?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Eny</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Tsia</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Ajanony</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(adika)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Haverezana ny fitehirizana ny rakitra </translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Anglisy</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Rosiana</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Alemanina</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Frantsay</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Frantsay avy amin&apos;ny Suisse</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Nisy tsy nety ny fandefasana ny encoder ...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Tsy misy Podcast encoder azo alaina ...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Ampahany %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>eo amin&apos;ny sehatr&apos;asanao ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>ao anatin&apos;ny fitoeran-drakitra %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast voaforona %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Nisy tsy nety ny fandraiketana ny Podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Fidirana feo tsotra</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Tsy misy ny fandraiketana ny feo</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kely</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Salasala</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Feno</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Alefa amin&apos;ny tranon-kala anatiny</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Alefa amin&apos;ny Youtube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>kinova:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Ny penina lehibe dia sarotiny amin&apos;ny fitsindrina</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Fidirana Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Anaran&apos;ny mpampiasa:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Teny fanalahidy:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Apetraka amin&apos;ny tranon-kala ny rakitra</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Lohateny:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Fanazavana:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Alefa</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Ny sarimietsiko</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Mamorona kisarisary ho hita aloha ...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 ny  kisarisary no voaforona ...</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pejy %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Compass</source>
        <translation>Famantaranavaratra</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Fanipihana</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Rapporteur</translation>
    </message>
    <message>
        <source>Mask</source>
        <translation>Tasova</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Telolafy</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Fanita-jery</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Tahiry</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Pejy iray manontolo</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Tranon-kala</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Mpanavaozana ny rakitra</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>Mila fanavaozana ny rakitra.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Lalana ny dikamitovy:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Hizaha</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Avaozy</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Safidio ny fitoeran-drakitra asiana dikamitovy</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Nety ny fanavaozana ny rakitra!
Avereno alefa ny rindr&apos;asa ahafahana mampiasa ny rakitra novoazana azafady.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Nisy tsy nety tamin&apos;ny fanavaozana. Tsy niova ny rakitra.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Valin&apos;ny fanavaozana ny rakitra</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Manavao an&apos;ilay rakitra</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Mba endraso kely azafady, anomboka tsy ho ela ny fanafarana ...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Ampatsiahivo ana amin&apos;ny manaraka</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Maka ...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 voaantso ( paika = %1, fandehany=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Famantarana YouTube tsy nety.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Nisy tsy fetezana tamin&apos;ny fandefasana ny horonan-tsary amin&apos;ny YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Fandefasana ho an&apos;ny YouTube am-pandehanana %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Fandefasana</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Fiarakodia &amp; fiara</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Mozika</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Biby</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Fanatajahan-tena</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Dia &amp; zava-miseho</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Filalaovana</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Mampiomehy</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Olona &amp; Blogs</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Vaovao &amp; politika</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Kilalao</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Fianarana</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Ahoana no manao azy &amp; Haingo</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Tsy misy tombony &amp; Fandraisana andraikitra</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Siansa &amp; Teknolojia</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Diovy</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Raiketo ny rakitra</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Fakana najanona: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Nisy tsy nety tamin&apos;ny fanokafana ny rakitra voatahiry: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Nisy tsy nety tamin&apos;ny fandraiketana: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Nisy tsy nety tamin&apos;ny rezo: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segondra</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minitra</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 sisa</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 amin&apos;ny %2 (%3 isakin&apos;ny segondra) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 amin&apos;ny %2 - Najanona</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 Nalaina</translation>
    </message>
    <message>
        <source>1 Download</source>
        <translation>Nalaina 1</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Lohateny</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adiresy</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Talohaloha androany</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 Zavatra</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hikaroka</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Vaovao &amp; Tab</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Asina dikamitovy ny Tab</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Idina ny Tab</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Idina &amp; ny Tab sasany</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Averina aseho ny Tab</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Averina aseho ny Tab rehetra</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Ny Tab nidina vao vetivety</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>( Tsy misy lohateny)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Hikaroka</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Tsy misy karoka vao natao vetivety</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Karoka vao natao vetivety</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Fafao ny karoka vao natao vetivety</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Nalaina</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Ampiana amn&apos;ny rakitra iasana</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Nisy tsy nety tamin&apos;ny fanafarana ny pejy: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Sokafy amin&apos;ny Tab vaovao</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Ametraka Podcast amin&apos;ny Youtube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Lohateny</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Fanazavana</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Teny mahasarika</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Antoko</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Anaran&apos;ny mpampiasa Youtube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Teny fanalahidy Youtube</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Rehefa tsindrinao ny &quot;Alefa&quot; dia manamarina ianao fa manana ny alalana rehetra ami&apos;ny mpiatiny na nomen&apos;ny mpamorona alalana ianao andefa an&apos;ilay rakitra amin&apos;ny YouTube.&lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>Opacity</source>
        <translation>Hateviny</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Amin&apos;ny ambadika mazava</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Amin&apos;ny ambadika maizina</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Sakan&apos;ny tsipika</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Salasala</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Matevina</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Tsara</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Ny penina dia sarotiny amin&apos;ny fitsindrina</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Fifakalozan-kevitra</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Lohateny</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>Mailaka</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Mpamorona</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Fanazavana</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Fifakalozan-kevitra</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Lohateny</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">Mailaka</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Mpamorona</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Fanazavana</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Safidy nofaritana</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Famaritana tsotra</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Hidio</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Asehoy</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Asehoy ny pejy miaraka ami&apos;ny mpizaha ivelany</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Fafan-teny virtoaly</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Haben&apos;ny kitendrin&apos;ny fafan-teny:</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Natao teo ambony (atoro ho an&apos;ny tablets)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Natao teo ambany (atoro ho an&apos;ny solaitra fotsy)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Asehoy ny lahateny eo ambanin&apos;ny bokotra</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Fanovana haingony</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Matory</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Mijidina</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Mombamomba</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Fanavaozana kirakira</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Jereo raha misy fanavaozana ny kirakira ami&apos;ny fandefasana</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Aterineto</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Pejin&apos;ny fandraisana:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Anjan&apos;ny fitaovana</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penina</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Penina lehibe</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>kinova: ...</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licences</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rezo</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Asehoy nympiatin&apos;ny pejin&apos;ny tranon-kala anaty amin&apos;ny efijery faharoa na amin&apos;ny projecteur</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Fisehoana maromaro</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Ampifanakaloza ny fisehoana ny mpibaiko sy ny fisehoana ny hita</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Fiasany</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Fiasany amin&apos;ny fandefasana an&apos;azy:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Solaitra</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Sehatr&apos;asa</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation> Mpampiasa ny Proxy:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Teny fanalahidy:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Voaka</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">Amin&apos;ny ambadika maizina</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">Hateviny</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">Amin&apos;ny ambadika mazava</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Alaina ny Flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>Safidio ny Flash ho alaina</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>Mombamomba: foana</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Anaran&apos;ny rindran&apos;asa</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Mamorona rindran&apos;asa</translation>
    </message>
</context>
</TS>
